# Event Study package

Event Study package is an open-source python project created 
to facilitate the computation of financial event study analysis.

## Install

```bash
$ pip install eventstudy
```

## Documentation

You can read the full documentation [here](https://lemairejean-baptiste.github.io/eventstudy/).

Go through the [Get started section](https://lemairejean-baptiste.github.io/eventstudy/get_started.html) to discover through simple 
examples how to use the `eventstudy` package to run your event study for a single event or a sample of events.

Read the [API guide](https://lemairejean-baptiste.github.io/eventstudy/api/index.html) for more details on functions and their parameters.